==> nicotine-plus-3.2.8.tar.gz: nicotine-plus-3.2.8/README.md <==
# Nicotine+

<img src="pynicotine/gtkgui/icons/hicolor/scalable/apps/org.nicotine_plus.Nicotine.svg" align="right" width="128" height="128" style="margin: 0 10px">

Nicotine+ is a graphical client for the [Soulseek](https://www.slsknet.org/) peer-to-peer network.

Nicotine+ aims to be a pleasant, free and open source (FOSS) alternative to the official Soulseek client, providing additional functionality while keeping current with the Soulseek protocol.

Nicotine+ is written in Python and uses GTK for its graphical user interface.

Check out the [screenshots](data/screenshots/SCREENSHOTS.md) and [source code](https://github.com/nicotine-plus/nicotine-plus).
<br clear="right">


## Download

The current stable version of Nicotine+ is 3.2.8, released on January 6, 2023. See the [release notes](NEWS.md).

Downloads are available for:

 * [GNU/Linux, *BSD and Solaris](doc/DOWNLOADS.md#gnulinux-bsd-solaris)
 * [Windows](doc/DOWNLOADS.md#windows)
 * [macOS](doc/DOWNLOADS.md#macos)


## Get Involved

If you feel like contributing to Nicotine+, there are several ways to get involved:

 * [Issue Tracker](https://github.com/nicotine-plus/nicotine-plus/issues) – Report a problem or suggest improvements
 * [Testing](doc/TESTING.md) – Download the latest unstable build and help test Nicotine+
 * [Translations](doc/TRANSLATIONS.md) – Translate Nicotine+ into another language with [Weblate](https://hosted.weblate.org/engage/nicotine-plus)
 * [Packaging](doc/PACKAGING.md) – Package Nicotine+ for a distribution or operating system
 * [Development](doc/DEVELOPING.md) – Implement bug fixes, enhancements or new features
 * [IRC Channel](https://web.libera.chat/?channel=#nicotine+) – Chat in the #nicotine+ IRC channel on [Libera.Chat](https://libera.chat/)


## Where did the name Nicotine come from?

> I was in a geeky mood and was browsing [http://www.bash.org](http://www.bash.org)'s QDB.  
I stumbled across [this quote](http://www.bash.org/?10159):  
>> **\<etc>** so tempting to release a product called 'nicotine' and wait for the patches.  
>> **\<etc>** then i would have a reason to only apply one patch a day. otherwise, i'm going against medical advise.  
>
> So I thought what the hell and bluntly stole etc's idea.  

<p align="right">Hyriand, <i>former Nicotine maintainer</i>, 2003</p>


## Legal and Privacy

Nicotine+ does not collect any user data. Different policies may apply to the default Soulseek server, which is not operated by the Nicotine+ Team.

When connecting to the default Soulseek server, you agree to abide by the Soulseek [rules](https://www.slsknet.org/news/node/681) and [terms of service](https://www.slsknet.org/news/node/682).


## Authors

Nicotine+ is free and open source software, released under the terms of the [GNU Public License v3](https://www.gnu.org/licenses/gpl-3.0-standalone.html) or later. Nicotine+ exists thanks to its [core contributors](AUTHORS.md), [translators](TRANSLATORS.md) and [other contributions](https://github.com/nicotine-plus/nicotine-plus/graphs/contributors).

==> nicotine-plus-3.3.0.tar.gz: nicotine-plus-3.3.0/README.md <==
# Nicotine+

<img src="pynicotine/gtkgui/icons/hicolor/scalable/apps/org.nicotine_plus.Nicotine.svg" align="right" width="128" height="128" style="margin: 0 10px">

Nicotine+ is a graphical client for the [Soulseek](https://www.slsknet.org/) peer-to-peer network.

Nicotine+ aims to be a lightweight, pleasant, free and open source (FOSS) alternative to the official Soulseek client, while also providing a comprehensive set of features.

Nicotine+ is written in Python and uses GTK for its graphical user interface.

Check out the [screenshots](data/screenshots/SCREENSHOTS.md) and [source code](https://github.com/nicotine-plus/nicotine-plus).
<br clear="right">


## Download

The current stable version of Nicotine+ is 3.3.0, released on February 1, 2024. See the [release notes](NEWS.md).

Downloads are available for:

 * [GNU/Linux, *BSD and Solaris](doc/DOWNLOADS.md#gnulinux-bsd-solaris)
 * [Windows](doc/DOWNLOADS.md#windows)
 * [macOS](doc/DOWNLOADS.md#macos)


## Get Involved

If you feel like contributing to Nicotine+, there are several ways to get involved:

 * [Issue Tracker](https://github.com/nicotine-plus/nicotine-plus/issues) – Report a problem or suggest improvements
 * [Testing](doc/TESTING.md) – Download the latest unstable build and help test Nicotine+
 * [Translations](doc/TRANSLATIONS.md) – Translate Nicotine+ into another language with [Weblate](https://hosted.weblate.org/engage/nicotine-plus)
 * [Packaging](doc/PACKAGING.md) – Package Nicotine+ for a distribution or operating system
 * [Development](doc/DEVELOPING.md) – Implement bug fixes, enhancements or new features
 * [IRC Channel](https://web.libera.chat/?channel=#nicotine+) – Chat in the #nicotine+ IRC channel on [Libera.Chat](https://libera.chat/)


## Where did the name Nicotine come from?

> I was in a geeky mood and was browsing http://www.bash.org's QDB.  
I stumbled across this quote:  
>> **\<etc>** so tempting to release a product called 'nicotine' and wait for the patches.  
>> **\<etc>** then i would have a reason to only apply one patch a day. otherwise, i'm going against medical advise.  
>
> So I thought what the hell and bluntly stole etc's idea.  

<p align="right">Hyriand, <i>former Nicotine maintainer</i>, 2003</p>


## Legal and Privacy

Nicotine+ does not collect any user data. Different policies may apply to the default Soulseek server, which is not operated by the Nicotine+ Team.

When connecting to the default Soulseek server, you agree to abide by the Soulseek [rules](https://www.slsknet.org/news/node/681) and [terms of service](https://www.slsknet.org/news/node/682).

Soulseek is an unencrypted protocol not intended for secure communication.


## Authors

Nicotine+ is free and open source software, released under the terms of the [GNU Public License v3](https://www.gnu.org/licenses/gpl-3.0-standalone.html) or later. Nicotine+ exists thanks to its [core team](AUTHORS.md), [translators](TRANSLATORS.md) and [contributors](https://github.com/nicotine-plus/nicotine-plus/graphs/contributors).
